@@ -16,7 +16,7 @@ from jinja2 import (
     PackageLoader
 )
 from jinja2.sandbox import SandboxedEnvironment
-
+from ..form import create_wtform_from_schema
 
 PROJECTS_DIR = 'projects'
 
@@ -61,18 +61,22 @@ def store_nexus_data(nexus_name, data):
 
 def get_render_form_kwargs(nexus_name):
     return {
-        'asset_url': get_asset_url,
+        'asset_url': lambda fn: get_asset_url(nexus_name, fn),
         'config': load_json(f'{PROJECTS_DIR}/{nexus_name}/', 'config.json'),
+        #'data': get_nexus_data(nexus_name),
         'nexus': nexus_name
     }
 
 
 def get_render_nexus_kwargs(nexus_name):
+    form_schema = load_json(f'{PROJECTS_DIR}/{nexus_name}/', 'form.json')
+    data = get_nexus_data(nexus_name)
+    form_cls = create_wtform_from_schema(form_schema)
     return {
         'asset_url': lambda fn: get_asset_url(nexus_name, fn),
         'config': load_json(f'{PROJECTS_DIR}/{nexus_name}/', 'config.json'),
-        'form_schema': load_json(f'{PROJECTS_DIR}/{nexus_name}/', 'form.json'),
-        'data': get_nexus_data(nexus_name),
+        'form_schema': form_schema,
+        'form': form_cls(**data),
         'nexus': nexus_name
     }
 
